@@ -1,18 +1,18 @@
 /***************************************************************************
  * aspline.c -- aspline does an Akima spline interpolation.                *
- * 								           *
- * spline is (c) David Frey, 1996, 1998					   *
- *								           * 
+ *                                                                         *
+ * spline is  David Frey, 1996, 1998, 1999                                *
+ *                                                                         * 
  * This program is free software; you can redistribute it and/or modify it *
  * under the terms of the GNU General Public License as published by the   *
  * Free Software Foundation; either version 2 of the License, or (at your  *
  * option) any later version.                                              *
- *									   * 
+ *                                                                         * 
  * This program is distributed in the hope that it will be useful, but     *
  * WITHOUT ANY WARRANTY; without even the implied warranty of              *
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
  * General Public License for more details.                                *
- *									   * 
+ *                                                                         * 
  * You should have received a copy of the GNU General Public License       *
  * along with this program; if not, write to the Free Software Foundation, *
  * Inc., 59 Temple Place Suite 330, Boston, MA 02111-1307 USA.             *
@@ -29,12 +29,12 @@
 
 #include "utils.h"
 
-#define DXSTEP		1.0
-#define INTERVALLS	100
+#define DXSTEP          1.0
+#define INTERVALLS      100
 
 char *progname;
 
-float *x, *y;		/* the values to interpolate */
+float *x, *y;           /* the values to interpolate */
 
 static struct option const long_options[] = {
   {"auto",     optional_argument, 0, 'a'},
@@ -50,7 +50,7 @@ static struct option const long_options[] = {
   {0,          0,                 0, 0  }
 };
 
-int warranty(void)		
+int warranty(void)              
      /* say that there is no warranty */
 {
   printf("\
@@ -86,7 +86,7 @@ int usage(void)
   -v, --verbose       be verbose.
   -V, --version       display version and copyright information and exit.
   -W, --warranty      display licensing terms.\n", 
-	  progname);
+          progname);
 
   exit(0);
 }
@@ -114,8 +114,8 @@ void insertpoint(char *inname, float xv, float yv, int *n)
     x[*n]=xv; y[*n]=yv; (*n)++; 
   } else if (xv == x[k]) { /* duplicate */
     fprintf(stderr, 
-	    "%s:%s: duplicate abscissas found, sample (%g,%g), dropped.\n", 
-	    progname, inname, xv,yv);
+            "%s:%s: duplicate abscissas found, sample (%g,%g), dropped.\n", 
+            progname, inname, xv,yv);
   } else { /* intermediate point. Insert it */
     x=xrealloc(x, (*n+1)*sizeof(float)); y=xrealloc(y, (*n+1)*sizeof(float)); 
 
@@ -140,7 +140,7 @@ void computelimits(int s, int e, float *llimit, float *ulimit)
 }
 
 void calcspline(int n, int d, float xstep, float llimit, float ulimit,
-		int calclimit)
+                int calclimit)
      /* Calculate the spline and output the result on stdout */
 {
   if (n > 0) { /* we have data to process */
@@ -160,15 +160,15 @@ void calcspline(int n, int d, float xstep, float llimit, float ulimit,
 
       m=dy/dx; /* dx != 0.0 asserted by insertpoint */
       for (i=0; i <= d; i++) 
-	printf("%g %g\n", x[0]+i*xstep, y[0]+i*m*xstep);
+        printf("%g %g\n", x[0]+i*xstep, y[0]+i*m*xstep);
     } else { /* now we have something to compute */
-      int i, k, p;	        /* n=no of points */
-      float *dx, *dy; 	        /* x[i+1]-x[i], resp. y[i+1]-y[i] */
-      float *m, *t;		/* the slopes */
-      float *C, *D;	        /* the coefficients */
+      int i, k, p;              /* n=no of points */
+      float *dx, *dy;           /* x[i+1]-x[i], resp. y[i+1]-y[i] */
+      float *m, *t;             /* the slopes */
+      float *C, *D;             /* the coefficients */
 
       /* Leading extrapolation points, 
-	 actual values will be filled in later */
+         actual values will be filled in later */
 
       x=(float *)xrealloc(x, (n+4) * sizeof(float));
       y=(float *)xrealloc(y, (n+4) * sizeof(float));
@@ -193,8 +193,8 @@ void calcspline(int n, int d, float xstep, float llimit, float ulimit,
       /* a) Calculate the differences and the slopes m[i]. */
 
       for (i=2; i < n-3; i++) {
-	dx[i]=x[i+1] - x[i]; dy[i]=y[i+1] - y[i]; 
-	m[i] =dy[i]/dx[i]; /* dx != 0, asserted by insertpoint() */
+        dx[i]=x[i+1] - x[i]; dy[i]=y[i+1] - y[i]; 
+        m[i] =dy[i]/dx[i]; /* dx != 0, asserted by insertpoint() */
       }
 
       /* b) interpolate the missing points: */
@@ -214,21 +214,21 @@ void calcspline(int n, int d, float xstep, float llimit, float ulimit,
       y[n-1]=(2*m[n-3] - m[n-4])*(x[n-1] - x[n-2]) + y[n-2];
 
       for (i=n-3; i < n-1; i++) {
-	dx[i]=x[i+1] - x[i]; dy[i]=y[i+1] - y[i];
-	 m[i]=dy[i]/dx[i];
+        dx[i]=x[i+1] - x[i]; dy[i]=y[i+1] - y[i];
+         m[i]=dy[i]/dx[i];
       }
 
       /* the first x slopes and the last y ones are extrapolated: */
 
       t[0]=0.0; t[1]=0.0;  /* not relevant */
       for (i=2; i < n-2; i++) {
-	float num, den;
+        float num, den;
 
-	num=fabs(m[i+1] - m[i])*m[i-1] + fabs(m[i-1] - m[i-2])*m[i];
-	den=fabs(m[i+1] - m[i]) + fabs(m[i-1] - m[i-2]);
+        num=fabs(m[i+1] - m[i])*m[i-1] + fabs(m[i-1] - m[i-2])*m[i];
+        den=fabs(m[i+1] - m[i]) + fabs(m[i-1] - m[i-2]);
 
-	if (den != 0.0) t[i]=num/den;
-	else            t[i]=0.0;
+        if (den != 0.0) t[i]=num/den;
+        else            t[i]=0.0;
       }
 
       /* c) Allocate the polynom coefficients */
@@ -239,10 +239,10 @@ void calcspline(int n, int d, float xstep, float llimit, float ulimit,
          D=(float *)xmalloc(n * sizeof(float));
 
       for (i=2; i < n-2; i++) {
-	/* A[i]=y[i]; 
-	   B[i]=t[i]; */
-  	   C[i]=(3*m[i] - 2*t[i] - t[i+1])/dx[i];
-	   D[i]=(t[i] + t[i+1] - 2*m[i])/(dx[i]*dx[i]);
+        /* A[i]=y[i]; 
+           B[i]=t[i]; */
+           C[i]=(3*m[i] - 2*t[i] - t[i+1])/dx[i];
+           D[i]=(t[i] + t[i+1] - 2*m[i])/(dx[i]*dx[i]);
       }
 
       /* 3rd step: output the coefficients for the subintervalls i=2..n-4 */
@@ -253,23 +253,23 @@ void calcspline(int n, int d, float xstep, float llimit, float ulimit,
 
       p=2;
       for (i=0; i <= d; i++) {
-	float xv;
+        float xv;
 
-	xv=llimit + i*xstep;
+        xv=llimit + i*xstep;
 
-	if (xv > x[p]) {
-	  printf("%g %g\n", x[p], y[p]); p++;
-	}
-	
-	k=2; while (xv >= x[k]) k++;	     /* XXX */
-	k--;
-
-	if (k != p) {
-	  printf("%g %g\n", xv,
-	         y[k] + t[k] * (xv-x[k]) + 
-	         C[k] * pow((xv-x[k]),2) + D[k] * pow((xv-x[k]),3));
+        if (xv > x[p]) {
+          printf("%g %g\n", x[p], y[p]); p++;
         }
-	if (xv > x[p]) p++;
+        
+        k=2; while (xv >= x[k]) k++;         /* XXX */
+        k--;
+
+        if (k != p) {
+          printf("%g %g\n", xv,
+                 y[k] + t[k] * (xv-x[k]) + 
+                 C[k] * pow((xv-x[k]),2) + D[k] * pow((xv-x[k]),3));
+        }
+        if (xv > x[p]) p++;
       }
       free(dx); free(dy); free(m); free(t);
     }    
@@ -277,8 +277,8 @@ void calcspline(int n, int d, float xstep, float llimit, float ulimit,
 }
 
 void readandcalcspline(FILE *infile, char *inname,
-		       int d, float xstep, float llimit, float ulimit,
-		       int calclimit, int verbose, int *s)
+                       int d, float xstep, float llimit, float ulimit,
+                       int calclimit, int verbose, int *s)
      /* s is the dataset number */
 {
   int n, l;
@@ -288,8 +288,8 @@ void readandcalcspline(FILE *infile, char *inname,
     infile=fopen(inname, "r");
     if (infile == NULL) {
       fprintf(stderr, 
-	      "%s: can't open \"%s\": %s.\n", 
-	      progname, inname, strerror(errno));
+              "%s: can't open \"%s\": %s.\n", 
+              progname, inname, strerror(errno));
       return;
     }
   }
@@ -311,24 +311,24 @@ void readandcalcspline(FILE *infile, char *inname,
 
     if ((line == NULL) || (il[0] == '\0')) {
       if (n > 0) {
-	if (*s > 0) printf("\n"); 
-	calcspline(n, d, xstep, llimit, ulimit, calclimit); (*s)++;
-	free(x); free(y); x=y=NULL; n=0;
+        if (*s > 0) printf("\n"); 
+        calcspline(n, d, xstep, llimit, ulimit, calclimit); (*s)++;
+        free(x); free(y); x=y=NULL; n=0;
       }    
     } else if (il[0] != '#') {
-      int k;	               /* number of values */
-      float f1, f2;	       /* floating point numbers */
+      int k;                   /* number of values */
+      float f1, f2;            /* floating point numbers */
 
       /* read point */
       k=sscanf(line, "%f %f", &f1, &f2);
 
       if (k < 1) 
-	fprintf(stderr, "%s:%s:%d: parse error at '%s'\n",
-		progname, inname, l, line);
+        fprintf(stderr, "%s:%s:%d: parse error at '%s'\n",
+                progname, inname, l, line);
       else if (k==1) 
-	insertpoint(inname, llimit+n*xstep,f1,&n); /* Auto xscale */
+        insertpoint(inname, llimit+n*xstep,f1,&n); /* Auto xscale */
       else
-	insertpoint(inname,f1,f2,&n);
+        insertpoint(inname,f1,f2,&n);
     }
   }
   while (line != NULL);
@@ -340,7 +340,7 @@ int main(int argc, char *argv[])
 {
   int c;
   int i,d;
-  float xstep, llimit, ulimit;	/* x-spacing, lower limit, upper limit */
+  float xstep, llimit, ulimit;  /* x-spacing, lower limit, upper limit */
   int calclimit, verbose;       /* calculate limits, be verbose */
 
   progname=strrchr(argv[0], '/');
@@ -354,7 +354,7 @@ int main(int argc, char *argv[])
 
   verbose=0; calclimit=1; xstep=DXSTEP; llimit=ulimit=0.0; d=INTERVALLS;
   while ((c = getopt_long(argc, argv, "a:?l:n:u:vVW",
-			  long_options, (int *)0)) != EOF) {
+                          long_options, (int *)0)) != EOF) {
     switch (c) {
       case 0:   break;
       case 'a': xstep=strtod(optarg, NULL);
@@ -366,22 +366,19 @@ int main(int argc, char *argv[])
       case 'n': d=atoi(optarg); break;
       case 'u': ulimit=strtod(optarg, NULL); calclimit=0; break;
       case 'v': verbose++; break;
-      case 'V': fprintf(stderr, "%s version %s\n", progname, VERSION);
-		return 0; break;
+      case 'V': fprintf(stderr, "%s version %s\n"
+"Akima spline interpolation  1996-1998 David Frey.\n"
+"This is free software; see the GNU General Public Licence version 2 or "
+"later\n"
+"for copying conditions.\n"
+"There is NO warranty.  See %s --licence for details.\n",
+			progname, VERSION, progname);
+                return 0; break;
       case 'W': warranty(); break;
       default : break;
     }
   }
 
-  fprintf(stderr,
-	  "Akima spline interpolation, aspline %s.\n"
-	  "Copyright 1996-1998 David Frey.  This is free software; see the "
-	  "GNU\n"
-	  "General Public Licence version 2 or later for copying conditions.  "
-	  "There\n"
-	  "is NO warranty.  See %s --licence for details.\n", 
-	  VERSION, progname);
-
   if (ulimit < llimit) {
     float temp;
 
@@ -394,8 +391,8 @@ int main(int argc, char *argv[])
     s=0;
     for (i=optind; i < argc; i++) {
       readandcalcspline(NULL, argv[i], 
-			d, xstep, llimit, ulimit, calclimit, verbose,
-			&s);
+                        d, xstep, llimit, ulimit, calclimit, verbose,
+                        &s);
 
       if ((s > 0) && (i < argc-1)) printf("\n"); 
       s++;
@@ -405,8 +402,8 @@ int main(int argc, char *argv[])
 
     s=0;
     readandcalcspline(stdin, "stdin", 
-		      d, xstep, llimit, ulimit, calclimit, verbose, 
-		      &s);
+                      d, xstep, llimit, ulimit, calclimit, verbose, 
+                      &s);
   }
   return 0;
 }
